//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[ShantenWithoutGot](index.md)/[goodShapeAdvance](good-shape-advance.md)

# goodShapeAdvance

[common]\

@EncodeDefault

val [goodShapeAdvance](good-shape-advance.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;?

好型进张 仅当一向听时进行计算
